@@ -92,7 +92,6 @@
 
 (defvar haskell-literate)
 
-;;;###autoload
 (defgroup haskell-indent nil
   "Haskell indentation."
   :group 'haskell
@@ -126,7 +125,7 @@
 (defconst haskell-indent-start-keywords-re
   (concat "\\<"
           (regexp-opt '("class" "data" "import" "infix" "infixl" "infixr"
-                        "instance" "module" "newtype" "primitive" "type") t)
+                        "instance" "module" "newtype" "primitive" "signature" "type") t)
           "\\>")
   "Regexp for keywords to complete when standing at the first word of a line.")
 
@@ -435,7 +434,8 @@ Returns the location of the start of the comment, nil otherwise."
         (haskell-indent-skip-blanks-and-newlines-forward end))))
 
 (defun haskell-indent-next-symbol-safe (end)
-  "Puts point to the next following symbol, or to end if there are no more symbols in the sexp."
+  "Puts point if there are no more symbols in the sexp.
+The point is put to the next following symbol, or to end."
   (condition-case _errlist (haskell-indent-next-symbol end)
     (error (goto-char end))))
 
@@ -1233,7 +1233,7 @@ START if non-nil is a presumed start pos of the current definition."
                    (setq open (haskell-indent-offset-after-info)))
           (list (list (haskell-indent-after-keyword-column open start))))))
 
-     ;; open structure? ie  ( { [
+     ;; open structure? i.e.  ( { [
      ((setq open (haskell-indent-open-structure start (point)))
       (haskell-indent-inside-paren open))
 
@@ -1324,7 +1324,7 @@ of the regions to move."
 (defun haskell-indent-align-def (p-arg type)
   "Align guards or rhs within the current definition before point.
 If P-ARG is t align all defs up to the mark.
-TYPE is either 'guard or 'rhs."
+TYPE is either \\='guard or \\='rhs."
   (save-excursion
     (let (start-block end-block
                       (maxcol (if (eq type 'rhs) haskell-indent-rhs-align-column 0))
@@ -1435,7 +1435,7 @@ TYPE is either 'guard or 'rhs."
 
 (defun haskell-indent-align-guards-and-rhs (_start _end)
   "Align the guards and rhs of functions in the region, which must be active."
-  ;; The `start' and `end' args are dummys right now: they're just there so
+  ;; The `start' and `end' args are dummies right now: they're just there so
   ;; we can use the "r" interactive spec which properly signals an error.
   (interactive "*r")
   (haskell-indent-align-def t 'guard)
@@ -1489,9 +1489,8 @@ One indentation cycle is used."
 
 ;;; haskell-indent-mode
 
-(defvar haskell-indent-mode nil
+(defvar-local haskell-indent-mode nil
   "Non-nil if the semi-intelligent Haskell indentation mode is in effect.")
-(make-variable-buffer-local 'haskell-indent-mode)
 
 (defvar haskell-indent-map
   (let ((map (make-sparse-keymap)))
@@ -1517,8 +1516,8 @@ One indentation cycle is used."
              (fboundp 'haskell-indentation-mode))
     (haskell-indentation-mode 0))
 
-  (set (make-local-variable 'indent-line-function) 'haskell-indent-cycle)
-  (set (make-local-variable 'indent-region-function) 'haskell-indent-region)
+  (setq-local indent-line-function 'haskell-indent-cycle)
+  (setq-local indent-region-function 'haskell-indent-region)
   (setq haskell-indent-mode t)
   ;; Activate our keymap.
   (let ((map (current-local-map)))
@@ -1580,6 +1579,9 @@ these functions also align the guards and rhs of the current definition
     \\[haskell-indent-put-region-in-literate]
       makes the region a piece of literate code in a literate script
 
+If `ARG' is falsey, toggle `haskell-indent-mode'.  Else sets
+`haskell-indent-mode' to whether `ARG' is greater than 0.
+
 Invokes `haskell-indent-hook' if not nil."
   (interactive "P")
   (setq haskell-indent-mode
